@@ -142,8 +142,8 @@ def check_directory_setting(setting_name, setting_value, default_value,
     elif not os.path.isdir(setting_value):
         results.error("Setting '%s' points to directory '%s', which does not exist" %
                       (setting_name, setting_value))
-    elif string.find(os.path.abspath(setting_value),
-                     os.path.abspath(app_dir_path)) != 0:
+    elif string.find(os.path.realpath(setting_value),
+                     os.path.realpath(app_dir_path)) != 0:
         results.error("Setting '%s' points to directory '%s', which is not a subdirectory of '%s'" %
                       (setting_name, setting_value, app_dir_path))
     else:
